<?php

namespace Drupal\ggl_map_examples\Controller;

use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Block\BlockManager;
use Drupal\ggl_map\Ajax\UpdateMarkerIconCommand;
use Drupal\ggl_map_examples\GglMapExamplesHelper;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * The GGL Map examples controller.
 */
class GglMapExamplesController extends ControllerBase {

  /**
   * The block manager.
   *
   * @var \Drupal\Core\Block\BlockManager
   */
  private BlockManager $blockManager;

  /**
   * The GGL map examples helper service.
   *
   * @var \Drupal\ggl_map_examples\GglMapExamplesHelper
   */
  private GglMapExamplesHelper $gglMapExampleshelper;

  /**
   * {@inheritdoc}
   */
  public function __construct(BlockManager $blockManager, GglMapExamplesHelper $gglMapExamplesHelper) {
    $this->blockManager = $blockManager;
    $this->gglMapExampleshelper = $gglMapExamplesHelper;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('plugin.manager.block'),
      $container->get('ggl_map_examples.ggl_map_examples_helper'),
    );
  }

  /**
   * Single collection map controller.
   *
   * @return array
   *   The renderable array.
   *
   * @throws \Drupal\Component\Plugin\Exception\PluginException
   */
  public function singleMap() {
    return [
      '#theme' => 'example_page',
      '#side_menu' => $this->blockManager->createInstance('side_menu_block')->build(),
      '#content' => $this->blockManager->createInstance('single_map_block')->build(),
      '#attached' => [
        'library' => [
          'ggl_map_examples/page',
        ],
      ],
    ];
  }

  /**
   * Single collection map with custom marker icon controller.
   *
   * @return array
   *   The renderable array.
   *
   * @throws \Drupal\Component\Plugin\Exception\PluginException
   */
  public function singleMapMarkerIcon() {
    return [
      '#theme' => 'example_page',
      '#side_menu' => $this->blockManager->createInstance('side_menu_block')->build(),
      '#content' => $this->blockManager->createInstance('single_map_marker_icon_block')->build(),
      '#attached' => [
        'library' => [
          'ggl_map_examples/page',
        ],
      ],
    ];
  }

  /**
   * Single collection map with #overrideSettings controller.
   *
   * @return array
   *   The renderable array.
   *
   * @throws \Drupal\Component\Plugin\Exception\PluginException
   */
  public function singleMapOverrideSettings() {
    return [
      '#theme' => 'example_page',
      '#side_menu' => $this->blockManager->createInstance('side_menu_block')->build(),
      '#content' => $this->blockManager->createInstance('single_map_override_settings_block')->build(),
      '#attached' => [
        'library' => [
          'ggl_map_examples/page',
        ],
      ],
    ];
  }

  /**
   * Single collection map with location controller.
   *
   * @return array
   *   The renderable array.
   *
   * @throws \Drupal\Component\Plugin\Exception\PluginException
   */
  public function singleMapLocation() {
    return [
      '#theme' => 'example_page',
      '#side_menu' => $this->blockManager->createInstance('side_menu_block')->build(),
      '#content' => $this->blockManager->createInstance('single_map_location_block')->build(),
      '#attached' => [
        'library' => [
          'ggl_map_examples/page',
        ],
      ],
    ];
  }

  /**
   * Multiple collection map controller.
   *
   * @return array
   *   The renderable array.
   *
   * @throws \Drupal\Component\Plugin\Exception\PluginException
   */
  public function multiMap() {
    return [
      '#theme' => 'example_page',
      '#side_menu' => $this->blockManager->createInstance('side_menu_block')->build(),
      '#content' => $this->blockManager->createInstance('multi_map_block')->build(),
      '#attached' => [
        'library' => [
          'ggl_map_examples/page',
        ],
      ],
    ];
  }

  /**
   * Multiple collection map with clustering controller.
   *
   * @return array
   *   The renderable array.
   *
   * @throws \Drupal\Component\Plugin\Exception\PluginException
   */
  public function multiMapCluster() {
    return [
      '#theme' => 'example_page',
      '#side_menu' => $this->blockManager->createInstance('side_menu_block')->build(),
      '#content' => $this->blockManager->createInstance('multi_map_cluster_block')->build(),
      '#attached' => [
        'library' => [
          'ggl_map_examples/page',
        ],
      ],
    ];
  }

  /**
   * Multiple collection map with trigger controller.
   *
   * @return array
   *   The renderable array.
   *
   * @throws \Drupal\Component\Plugin\Exception\PluginException
   */
  public function mapTrigger() {
    return [
      '#theme' => 'example_page',
      '#side_menu' => $this->blockManager->createInstance('side_menu_block')->build(),
      '#content' => $this->blockManager->createInstance('map_trigger_block')->build(),
      '#attached' => [
        'library' => [
          'ggl_map_examples/page',
        ],
      ],
    ];
  }

  /**
   * Map with AJAX controller.
   *
   * @return array
   *   The renderable array.
   *
   * @throws \Drupal\Component\Plugin\Exception\PluginException
   */
  public function mapAjax() {
    return [
      '#theme' => 'example_page',
      '#side_menu' => $this->blockManager->createInstance('side_menu_block')->build(),
      '#content' => $this->blockManager->createInstance('map_ajax_block')->build(),
      '#attached' => [
        'library' => [
          'ggl_map_examples/page',
        ],
      ],
    ];
  }

  /**
   * AJAX callback for 'switch to red' links.
   *
   * @param string $markerId
   *   The marker id.
   *
   * @return \Drupal\Core\Ajax\AjaxResponse
   *   The AJAX response.
   */
  public function mapAjaxSwitchToRed($markerId) {
    $response = new AjaxResponse();
    $response->addCommand(new UpdateMarkerIconCommand($markerId, $this->gglMapExampleshelper->modulePath() . '/images/marker_red.svg'));

    return $response;
  }

}
