<?php

namespace Drupal\ggl_map_examples\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\ggl_map_examples\GglMapExamplesHelper;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * The GGL Map block with JS triggers to handle custom JS.
 *
 * @Block(
 *  id = "map_trigger_block",
 *  admin_label = @Translation("Map with trigger"),
 * )
 */
class MapTrigger extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * The GGL map examples helper service.
   *
   * @var \Drupal\ggl_map_examples\GglMapExamplesHelper|object|null
   */
  private GglMapExamplesHelper $gglMapExamplesHelper;

  /**
   * Constructs a block object.
   *
   * @param array $configuration
   *   The configuration.
   * @param string $plugin_id
   *   The plugin id.
   * @param mixed $plugin_definition
   *   The plugin definition.
   * @param \Drupal\ggl_map_examples\GglMapExamplesHelper $gglMapExamplesHelper
   *   The GGL maps examples helper service.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, GglMapExamplesHelper $gglMapExamplesHelper) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->gglMapExamplesHelper = $gglMapExamplesHelper;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration, $plugin_id, $plugin_definition,
      $container->get('ggl_map_examples.ggl_map_examples_helper')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    return [
      '#theme' => 'map_trigger',
      '#ggl_map' => [
        "#theme" => "ggl_map",
        '#collection' => [
          [
            'id' => 'single_map',
            'url' => $this->gglMapExamplesHelper->modulePath().'/data/single_collection.json',
          ],
        ],
      ],
      '#modulePath' => $this->gglMapExamplesHelper->modulePath(),
      '#attached' => [
        'library' => [
          'ggl_map_examples/map',
          'ggl_map_examples/map_trigger',
        ],
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheMaxAge() {
    return 0;
  }

}
