<?php

namespace Drupal\ggl_map_examples\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\ggl_map_examples\GglMapExamplesHelper;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Request;

/**
 * The side menu block for the example pages.
 *
 * @Block(
 *  id = "side_menu_block",
 *  admin_label = @Translation("Side menu"),
 * )
 */
class SideMenu extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * The GGL map examples helper service.
   *
   * @var \Drupal\ggl_map_examples\GglMapExamplesHelper|object|null
   */
  private GglMapExamplesHelper $gglMapExamplesHelper;

  /**
   * The request.
   *
   * @var \Symfony\Component\HttpFoundation\Request
   */
  private Request $request;

  /**
   * @param array $configuration
   *   The configuration.
   * @param string $plugin_id
   *   The plugin id.
   * @param mixed $plugin_definition
   *   The plugin definition.
   * @param \Drupal\ggl_map_examples\GglMapExamplesHelper $gglMapExamplesHelper
   *   The GGL map examples service.
   * @param \Symfony\Component\HttpFoundation\Request $request
   *   The request.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, GglMapExamplesHelper $gglMapExamplesHelper, Request $request) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->gglMapExamplesHelper = $gglMapExamplesHelper;
    $this->request = $request;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration, $plugin_id, $plugin_definition,
      $container->get('ggl_map_examples.ggl_map_examples_helper'),
      $container->get('request_stack')->getCurrentRequest()
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    return [
      '#theme' => 'side_menu',
      '#items' => $this->gglMapExamplesHelper->sideMenuItems(),
      '#requestUri' => $this->request->getRequestUri(),
    ];
  }

}
