(function ($, Drupal, drupalSettings) {
  'use strict';

  Drupal.gglMapPaths = Drupal.gglMapPaths || {};
  Drupal.gglMapPaths.allPaths = Drupal.gglMapPaths.allPaths || {};
  Drupal.gglMapPaths.allPoints = Drupal.gglMapPaths.allPoints || [];

  /**
   * Initialize the markers based on the data coming from the collection.
   * @param collection
   * @param collectionData
   */
  Drupal.gglMapPaths.initPaths = function (collection, collectionData) {
    let _self = this;

    if ("items" in collectionData) {
      $.each(collectionData.items, function (index, pathData) {
        if ("id" in pathData) {
          _self.allPaths[pathData.id] = _self.createPath(collection, pathData);
        }
      });
    }
  };



  /**
   * Create polyline.
   * @param index
   * @param data
   */
  Drupal.gglMapPaths.createPath = function (index, data) {
    let _self = this;

    let settings = drupalSettings.gglMap.path;
    if (typeof data.icons !== 'undefined') {
      settings.icons = data.icons;
    }
    if (typeof data.strokeColor !== 'undefined') {
      settings.strokeColor = data.strokeColor;
    }
    if (typeof data.strokeOpacity !== 'undefined') {
      settings.strokeOpacity = data.strokeOpacity;
    }
    if (typeof data.strokeWeight !== 'undefined') {
      settings.strokeWeight = data.strokeWeight;
    }

    let path = new google.maps.Polyline(settings);

    let points = [];
    $.each(data.points, function (index, element) {
      points.push({'lat': element.lat[0], 'lng': element.lon[0]});
      _self.allPoints.push({'lat': element.lat[0], 'lng': element.lon[0]});
    });
    path.setPath(points);
    path.setMap(Drupal.gglMap.map);
    return path;
  };

  /**
   * Add collection to path.
   * @param collectionId
   * @param path
   */
  Drupal.gglMapPaths.addCollectionToPath = function (collectionId, path) {
    if (!('collection' in path.data)) {
      path.data.collection = [];
    }
    if (!path.data.collection.includes(collectionId)) {
      path.data.collection.push(collectionId);
    }
  };

})(jQuery, Drupal, drupalSettings);
